@@ -8,7 +8,7 @@ from enum import Enum
 
 from mashumaro import field_options
 
-from liminal.helpers.model import BaseResponseModel
+from liminal.helpers.model import BaseModel
 
 
 # Define enums to use as types:
@@ -20,15 +20,17 @@ class ModelProviderKey(str, Enum):
     AWS_SAGEMAKER = "aws_sagemaker"
     AZURE_OPENAI = "azure_openai"
     COHERE = "cohere"
+    GOOGLE_VERTEX_AI = "google_vertex_ai"
     HUGGINGFACE = "huggingface"
     MISTRAL = "mistral"
     OLLAMA = "ollama"
     OPENAI = "openai"
+    PERPLEXITY = "perplexity"
 
 
 @dataclass(frozen=True, kw_only=True)
-class ModelConnection(BaseResponseModel):
-    """Define the schema for an LLM model connection."""
+class ModelConnection(BaseModel):
+    """Define the model for an LLM model connection."""
 
     id: int
 
@@ -36,12 +38,8 @@ class ModelConnection(BaseResponseModel):
     model_instance_id: int = field(metadata=field_options(alias="modelInstanceId"))
 
     # Fields:
-    api_key: str | None = field(default=None, metadata=field_options(alias="apiKey"))
-    masked_api_key: str | None = field(
-        default=None, metadata=field_options(alias="maskedApiKey")
-    )
+    credentials: dict[str, str] | None = field(default_factory=dict)
     model: str
-    params: dict[str, str] | None = field(default_factory=dict)
     provider_key: ModelProviderKey = field(metadata=field_options(alias="providerKey"))
 
     # Timestamps:
@@ -53,8 +51,8 @@ class ModelConnection(BaseResponseModel):
 
 
 @dataclass(frozen=True, kw_only=True)
-class ModelInstance(BaseResponseModel):
-    """Define the schema for an LLM model instance that Liminal supports."""
+class ModelInstance(BaseModel):
+    """Define the model for an LLM model instance that Liminal supports."""
 
     id: int
 
